@@ -131,11 +131,26 @@ class RDSClient():
         document = self.select_query(query, fetchone=True)
         return document['name'], document['uri']
         
-            
     def insert_page(self,
-                    img_uri: str,
-                    document_id: int) -> int:
+                    document_id: int,
+                    img_uri: str = "",
+                    ocr_uri: str = "") -> int:
         """
         """
-        query = f'INSERT INTO neuralplatform_page(imgUri, ocrUri, document_id) VALUES ("{img_uri}", "", {document_id});'
+        query = f'INSERT INTO neuralplatform_page(imgUri, ocrUri, document_id) VALUES ("{img_uri}", "{ocr_uri}", {document_id});'
         return self.insert_query(query)
+    
+    def update_page_ocr(self,
+                        page_id: int,
+                        ocr_uri: str) -> int:
+        """
+        """
+        query = f'UPDATE neuralplatform_page SET ocrUri = "{ocr_uri}" WHERE id = {page_id};'
+        return self.insert_query(query)
+
+    def get_page(self,
+                 page_id: int):
+        """
+        """
+        query = f"SELECT * FROM neuralplatform_page WHERE id = {page_id};"
+        return self.select_query(query, fetchone=True)
\ No newline at end of file
